#
# spec file for package autossh
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if 0%{?suse_version} > 1220
%define with_systemd 1
%else
%define with_systemd 0
%endif

Summary:        Automatically restart SSH sessions and tunnels
License:        BSD-3-Clause
Group:          Productivity/Networking/SSH

Name:           autossh
Version:        1.4e
Release:        lp150.1.4
Url:            http://www.harding.motd.ca/autossh/
Source:         http://www.harding.motd.ca/autossh/%{name}-%{version}.tgz
Source1:        autossh.init
Source2:        autossh.conf
Source3:        autossh.service
Source4:        my.conf
Source5:        README.SUSE.md
Patch0:         autossh-makefile-destdir.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# configure checks is the ssh client exists
BuildRequires:  openssh
Requires:       openssh
%if %{with_systemd}
BuildRequires:  systemd
%{?systemd_requires}
%else
Requires(pre):  %fillup_prereq %insserv_prereq
%endif

%description
Autossh is a program to start a copy of ssh and monitor it, restarting
it as necessary should it die or stop passing traffic. The idea and
the mechanism are from rstunnel (Reliable SSH Tunnel), but implemented
in C. The author's view is that it is not as fiddly as rstunnel to get
to work. Connection monitoring using a loop of port forwardings. Backs
off on rate of connection attempts when experiencing rapid failures
such as connection refused.

%prep
%setup
%patch0 -p1
cp %{S:4} .
cp %{S:5} .

%build
%configure
%__make %{?jobs:-j%jobs}

%install
%makeinstall
%__mkdir_p %{buildroot}%{_sbindir}
%if %{with_systemd}
%__install -D -m 444 %{S:3} %{buildroot}%{_unitdir}/autossh@.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcautossh
%else
%__install -D -m 755 %{S:1} %{buildroot}%{_initrddir}/autossh
%__ln_s -f %{_initrddir}/autossh %{buildroot}%{_sbindir}/rcautossh
%__install -D -m 644 %{S:2} %{buildroot}%{_fillupdir}/sysconfig.autossh
%endif
%__rm "$RPM_BUILD_ROOT/usr/share/doc/autossh"/{CHANGES,README}
%__rm -rf "%{buildroot}%{_datadir}/examples"

%if %{with_systemd}
%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service
%endif

%post
%if %{with_systemd}
%service_add_post %{name}.service
%else
%fillup_only
%endif

%postun
%if %{with_systemd}
%service_del_postun %{name}.service
%else
%insserv_cleanup
%endif

%files
%defattr(-, root, root, 0755)
%doc CHANGES README README.SUSE.md my.conf
%doc autossh.host rscreen
%{_bindir}/autossh
%if %{with_systemd}
%{_unitdir}/%{name}@.service
%else
%{_initrddir}/autossh
%{_fillupdir}/sysconfig.autossh
%endif
%{_sbindir}/rcautossh
%doc %{_mandir}/man1/autossh.1*

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Sep 15 2015 multyrealm@gmail.com
- Update to version 1.4e
  + By default, changing the poll time should change the first poll
    time to match. Only have different times if AUTOSSH_FIRST_POLL
    is explicitly set. Jerry Xie forwarded on change request from
    Ubuntu bug forums.
* Wed May 13 2015 Greg.Freemyer@gmail.com
- Minor cleanups to service file and sample my.conf override file
* Fri Apr 24 2015 Greg.Freemyer@gmail.com
- change autossh.service content to reflect it is a READONLY file.
- change the install line for autossh.service to:
  %%__install -D -m 444 %%{S:3} %%{buildroot}%%{_unitdir}/autossh@.service
  * This has 2 big changes.  First the permissions are 444, so READONLY.
  * Second, note the @ char in the target name.
    This makes it an instantiated service file
- add a sample my.conf override file
- add a README.SUSE.md file that:
  * explains how to use systemd instantiated service
  * how to use the override file
  * a full walkthru of how to setup a reverse tunnel
* Thu Dec 18 2014 p.drouand@gmail.com
- Update to version 1.4d
  + call daemon() before opening any sockets. Problem discovered and
    diagnosed by Frank van der Aa when trying to start autossh at
    system init.
  + don't use malloc(n * size) idiom; use calloc()
* Sun Jul 20 2014 p.drouand@gmail.com
- Add systemd support for openSUSE > 12.2
* Wed Mar 27 2013 multyrealm@gmail.com
- support a custom count of instances
* Wed Mar 27 2013 multyrealm@gmail.com
- add functions to init script for controling autossh instances
* Fri Mar 22 2013 multyrealm@gmail.com
- change first autossh channel configuration key to
  the old one to make package update seemless
* Tue Mar 19 2013 multyrealm@gmail.com
- support upto 10 autossh instances
* Mon Mar 18 2013 multyrealm@gmail.com
- updated copyright year
* Wed Apr 18 2012 multyrealm@gmail.com
- updated autossh configuration options
* Mon Apr 16 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  See fakepoll.h (BSD-4-Clause with UCB clarification). There is no GPL in
  this package
* Fri Apr  6 2012 multyrealm@gmail.com
- added insserv_cleanup macro
* Fri Apr  6 2012 multyrealm@gmail.com
- added SysV-style initscript and configuration file fillup template
* Thu Apr  5 2012 meissner@suse.com
- a ssh connection watch daemon
